==> open-xchange-core_7.8.2.orig.tar.bz2: open-xchange-core-7.8.2/com.openexchange.rest.client/src/com/openexchange/rest/client/endpointpool/EndpointManager.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.rest.client.endpointpool;

import java.util.List;

/**
 * {@link EndpointManager} - Manages a list of end-points with the possibility to black-list unavailable ones (according to associated {@link EndpointAvailableStrategy strategy})
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.1
 */
public interface EndpointManager {

    /**
     * Gets an available end-point.
     *
     * @return The end-point or <code>null</code> if all end-points have been blacklisted
     */
    Endpoint get();

    /**
     * Checks if this end-point pool has any working/available end-point left.
     *
     * @return <code>true</code> if there is any available end-point; otherwise <code>false</code>
     */
    boolean hasAny();

    /**
     * Removes an end-point from the list of available ones and adds it to the blacklist.
     *
     * @param endpoint The end-point
     * @return <code>true</code> if there is any available end-point; otherwise <code>false</code>
     */
    boolean blacklist(Endpoint endpoint);

    /**
     * Removes an end-point from the blacklist and adds it back to list of available ones.
     *
     * @param endpoint The end-point
     */
    void unblacklist(Endpoint endpoint);

    /**
     * Closes this end-point pool instance. The blacklist heartbeat task is cancelled.
     */
    void close();

    /**
     * Gets the currently blacklisted end-points.
     *
     * @return The currently blacklisted end-points
     */
    List<Endpoint> getBlacklist();

}

==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.rest.client/src/com/openexchange/rest/client/endpointpool/EndpointManager.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.rest.client.endpointpool;

import java.util.List;

/**
 * {@link EndpointManager} - Manages a list of end-points with the possibility to black-list unavailable ones (according to associated {@link EndpointAvailableStrategy strategy})
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.1
 */
public interface EndpointManager {

    /**
     * Gets an available end-point.
     *
     * @return The end-point or <code>null</code> if all end-points have been blacklisted
     */
    Endpoint get();

    /**
     * Checks if this end-point pool has any working/available end-point left.
     *
     * @return <code>true</code> if there is any available end-point; otherwise <code>false</code>
     */
    boolean hasAny();

    /**
     * Removes an end-point from the list of available ones and adds it to the blacklist.
     *
     * @param endpoint The end-point
     * @return <code>true</code> if there is any available end-point; otherwise <code>false</code>
     */
    boolean blacklist(Endpoint endpoint);

    /**
     * Removes an end-point from the blacklist and adds it back to list of available ones.
     *
     * @param endpoint The end-point
     */
    void unblacklist(Endpoint endpoint);

    /**
     * Closes this end-point pool instance. The blacklist heartbeat task is cancelled.
     */
    void close();

    /**
     * Gets the currently blacklisted end-points.
     *
     * @return The currently blacklisted end-points
     */
    List<Endpoint> getBlacklist();

    /**
     * Gets the number of total end-points.
     *
     * @return The number of total end-points
     */
    int getNumberOfEndpoints();

}
